FilterKind

Enum FilterKind 

pub enum FilterKind {
    Text {
        placeholder: Option<Cow<'static, str>>,
    },
    Sort {
        can_ascend: bool,
        options: Vec<Cow<'static, str>>,
        default: Option<SortFilterDefault>,
    },
    Check {
        name: Option<Cow<'static, str>>,
        can_exclude: bool,
        default: Option<bool>,
    },
    Select {
        is_genre: bool,
        uses_tag_style: bool,
        options: Vec<Cow<'static, str>>,
        ids: Option<Vec<Cow<'static, str>>>,
        default: Option<Cow<'static, str>>,
    },
    MultiSelect {
        is_genre: bool,
        can_exclude: bool,
        uses_tag_style: bool,
        options: Vec<Cow<'static, str>>,
        ids: Option<Vec<Cow<'static, str>>>,
        default_included: Option<Vec<Cow<'static, str>>>,
        default_excluded: Option<Vec<Cow<'static, str>>>,
    },
    Note(Cow<'static, str>),
    Range {
        min: Option<f32>,
        max: Option<f32>,
        decimal: bool,
    },
}
The kind of filter.

Variants



Text

A text field.

Fields

placeholder: Option<Cow<'static, str>>


Sort

A list of sort options.

Fields

can_ascend: bool
options: Vec<Cow<'static, str>>


Check

A checkbox.

Fields

name: Option<Cow<'static, str>>
can_exclude: bool
default: Option<bool>


Select

A list of values that allows a single selection.

Fields

is_genre: bool
uses_tag_style: bool
options: Vec<Cow<'static, str>>
ids: Option<Vec<Cow<'static, str>>>
default: Option<Cow<'static, str>>


MultiSelect

A list of values that allows multiple selections.

Fields

is_genre: bool
can_exclude: bool
uses_tag_style: bool
options: Vec<Cow<'static, str>>
ids: Option<Vec<Cow<'static, str>>>
default_included: Option<Vec<Cow<'static, str>>>
default_excluded: Option<Vec<Cow<'static, str>>>


Note(Cow<'static, str>)

A block of text displayed in the filter menu.



Range

A range filter.

Fields

decimal: bool