HomeComponentValue

Enum HomeComponentValue 

pub enum HomeComponentValue {
    ImageScroller {
        links: Vec<Link>,
        auto_scroll_interval: Option<f32>,
        width: Option<i32>,
        height: Option<i32>,
    },
    BigScroller {
        entries: Vec<Manga>,
        auto_scroll_interval: Option<f32>,
    },
    Scroller {
        entries: Vec<Link>,
        listing: Option<Listing>,
    },
    MangaList {
        ranking: bool,
        page_size: Option<i32>,
        entries: Vec<Link>,
        listing: Option<Listing>,
    },
    MangaChapterList {
        page_size: Option<i32>,
        entries: Vec<MangaWithChapter>,
        listing: Option<Listing>,
    },
    Filters(Vec<FilterItem>),
    Links(Vec<Link>),
}
The value of a component for a home layout.

Variants



ImageScroller

A horizontal scroller of images.

Only the image urls and values of the provided links are used.

Fields

links: Vec<Link>
auto_scroll_interval: Option<f32>
width: Option<i32>
height: Option<i32>


BigScroller

A large scroller of manga.

This component displays the title, author, cover image, description, content rating and tags of the provided manga entries.

Fields

entries: Vec<Manga>
auto_scroll_interval: Option<f32>


Scroller

A small scroller of manga.

The subtitles of the provided links are not used.

Fields

entries: Vec<Link>
listing: Option<Listing>


MangaList

A list of manga.

Fields

ranking: bool

If the list should be displayed with ranking numbers.

page_size: Option<i32>
entries: Vec<Link>
listing: Option<Listing>


MangaChapterList

A list of manga chapters.

The relative time to the chapter’s date uploaded is displayed if provided.

Fields

page_size: Option<i32>
listing: Option<Listing>


Filters(Vec<FilterItem>)

A collection of links to filtered listings.

A list of links.

Only the link title and values are used.

Implementations

Source

impl HomeComponentValue

pub fn empty_image_scroller() -> Self

Creates an empty image scroller component.

pub fn empty_big_scroller() -> Self

Creates an empty big scroller component.

pub fn empty_scroller() -> Self

Creates an empty scroller component.

pub fn empty_manga_list() -> Self

Creates an empty manga list component.

pub fn empty_manga_chapter_list() -> Self

Creates an empty manga chapter list component.

pub fn empty_filters() -> Self

Creates an empty filters component.

Creates an empty links component.