PageContent

Enum PageContent 

pub enum PageContent {
    Url(String, Option<PageContext>),
    Text(String),
    Image(ImageRefPriv),
    Zip(String, String),
}
The content of a page.

Variants



Url(String, Option<PageContext>)

A url to an image, with associated context.

The context is sent to the page processor and/or image request modifier if the source implements either.



Text(String)

A markdown text string.



Image(ImageRefPriv)

A raw image.



Zip(String, String)

A url to zip archive and a file path to an image inside the archive.

Implementations

Source

impl PageContent

pub fn url<T: Into<String>>(url: T) -> Self

Create a new PageContent with a url.

pub fn url_context<T: Into<String>>(url: T, context: PageContext) -> Self

Create a new PageContent with a url and context.

pub fn text<T: Into<String>>(text: T) -> Self

Create a new PageContent with a markdown text string.

pub fn image(image: ImageRef) -> Self

Create a new PageContent with a raw image.