Viewer

Enum Viewer 

pub enum Viewer {
    Unknown = 0,
    LeftToRight = 1,
    RightToLeft = 2,
    Vertical = 3,
    Webtoon = 4,
}
The proper reading viewer for a manga.

This is used for automatic selection of the reader view in Aidoku. RightToLeft is used for manga, LeftToRight is for western comics, and Webtoon is used for manhwa and manhua.

Variants



Unknown = 0



LeftToRight = 1



RightToLeft = 2



Vertical = 3



Webtoon = 4