pub struct EditableListSetting {
pub key: Cow<'static, str>,
pub title: Cow<'static, str>,
pub notification: Option<Cow<'static, str>>,
pub requires: Option<Cow<'static, str>>,
pub requires_false: Option<Cow<'static, str>>,
pub refreshes: Option<Vec<Cow<'static, str>>>,
pub line_limit: Option<i32>,
pub inline: bool,
pub placeholder: Option<Cow<'static, str>>,
pub default: Option<Vec<Cow<'static, str>>>,
}Expand description
Fields
key: Cow<'static, str>The unique key that identifies this setting.
title: Cow<'static, str>The display title for this setting.
notification: Option<Cow<'static, str>>Optional notification to send to the source when this setting is changed.
requires: Option<Cow<'static, str>>Optional key of another setting that must be enabled for this setting to be enabled.
requires_false: Option<Cow<'static, str>>Optional key of another setting that must be disabled for this setting to be enabled.
refreshes: Option<Vec<Cow<'static, str>>>Optional list of items that should be refreshed when this setting changes.
The valid options are:
contentlistingssettings
line_limit: Option<i32>Optional maximum number of lines.
inline: boolWhether to display the list inline instead of in a separate page.
placeholder: Option<Cow<'static, str>>Optional placeholder text for new items.
default: Option<Vec<Cow<'static, str>>>The default list items.