pub struct Filter {
pub id: Cow<'static, str>,
pub title: Option<Cow<'static, str>>,
pub hide_from_header: Option<bool>,
pub kind: FilterKind,
}Expand description
A filter that can be used in a source search.
This struct shouldn’t be constructed directly. Instead, use the individual filter structs and call into.
Fields
id: Cow<'static, str>title: Option<Cow<'static, str>>hide_from_header: Option<bool>kind: FilterKindImplementations