GroupSetting

Struct GroupSetting 

pub struct GroupSetting {
    pub key: Cow<'static, str>,
    pub title: Cow<'static, str>,
    pub notification: Option<Cow<'static, str>>,
    pub requires: Option<Cow<'static, str>>,
    pub requires_false: Option<Cow<'static, str>>,
    pub refreshes: Option<Vec<Cow<'static, str>>>,
    pub footer: Option<Cow<'static, str>>,
    pub items: Vec<Setting>,
}
A group of settings.

This setting can be converted into a generic Setting using the Into trait.

Fields

key: Cow<'static, str>

The unique key that identifies this setting.

title: Cow<'static, str>

The display title for this setting.

notification: Option<Cow<'static, str>>

Optional notification to send to the source when this setting is changed.

requires: Option<Cow<'static, str>>

Optional key of another setting that must be enabled for this setting to be enabled.

requires_false: Option<Cow<'static, str>>

Optional key of another setting that must be disabled for this setting to be enabled.

refreshes: Option<Vec<Cow<'static, str>>>

Optional list of items that should be refreshed when this setting changes.

The valid options are:

  • content
  • listings
  • settings
footer: Option<Cow<'static, str>>

Optional footer text for the group.

items: Vec<Setting>

The settings contained in this group.