pub struct LinkSetting {
pub key: Cow<'static, str>,
pub title: Cow<'static, str>,
pub notification: Option<Cow<'static, str>>,
pub requires: Option<Cow<'static, str>>,
pub requires_false: Option<Cow<'static, str>>,
pub refreshes: Option<Vec<Cow<'static, str>>>,
pub url: Cow<'static, str>,
pub external: Option<bool>,
}Expand description
Fields
key: Cow<'static, str>The unique key that identifies this setting.
title: Cow<'static, str>The display title for this setting.
notification: Option<Cow<'static, str>>Optional notification to send to the source when this setting is changed.
requires: Option<Cow<'static, str>>Optional key of another setting that must be enabled for this setting to be enabled.
requires_false: Option<Cow<'static, str>>Optional key of another setting that must be disabled for this setting to be enabled.
refreshes: Option<Vec<Cow<'static, str>>>Optional list of items that should be refreshed when this setting changes.
The valid options are:
contentlistingssettings
url: Cow<'static, str>The URL to open on press.
external: Option<bool>Whether the link should open in an external browser.