pub struct LoginSetting {Show 16 fields
pub key: Cow<'static, str>,
pub title: Cow<'static, str>,
pub notification: Option<Cow<'static, str>>,
pub requires: Option<Cow<'static, str>>,
pub requires_false: Option<Cow<'static, str>>,
pub refreshes: Option<Vec<Cow<'static, str>>>,
pub method: LoginMethod,
pub url: Option<Cow<'static, str>>,
pub url_key: Option<Cow<'static, str>>,
pub logout_title: Option<Cow<'static, str>>,
pub pkce: bool,
pub token_url: Option<Cow<'static, str>>,
pub callback_scheme: Option<Cow<'static, str>>,
pub use_email: bool,
pub local_storage_keys: Option<Vec<String>>,
pub clear_cookies_on_log_out: bool,
}Expand description
Fields
key: Cow<'static, str>The unique key that identifies this setting.
title: Cow<'static, str>The display title for this setting.
notification: Option<Cow<'static, str>>Optional notification to send to the source when this setting is changed.
requires: Option<Cow<'static, str>>Optional key of another setting that must be enabled for this setting to be enabled.
requires_false: Option<Cow<'static, str>>Optional key of another setting that must be disabled for this setting to be enabled.
refreshes: Option<Vec<Cow<'static, str>>>Optional list of items that should be refreshed when this setting changes.
The valid options are:
contentlistingssettingsfilters
method: LoginMethodThe authentication method to use.
url: Option<Cow<'static, str>>The authentication URL.
url_key: Option<Cow<'static, str>>An optional defaults key to fetch the URL from.
logout_title: Option<Cow<'static, str>>The title for the logout button. If not provided, the title will be “Log Out”.
pkce: boolWhether to use PKCE for the OAuth flow.
token_url: Option<Cow<'static, str>>The token URL for OAuth.
callback_scheme: Option<Cow<'static, str>>The callback scheme for OAuth.
use_email: boolWhether to prompt for an email instead of username for basic authentication.
local_storage_keys: Option<Vec<String>>An array of localStorage keys to extract after login.
Whether to clear cookies from the web view on log out.