pub struct Manga {Show 14 fields
pub key: String,
pub title: String,
pub cover: Option<String>,
pub artists: Option<Vec<String>>,
pub authors: Option<Vec<String>>,
pub description: Option<String>,
pub url: Option<String>,
pub tags: Option<Vec<String>>,
pub status: MangaStatus,
pub content_rating: ContentRating,
pub viewer: Viewer,
pub update_strategy: UpdateStrategy,
pub next_update_time: Option<i64>,
pub chapters: Option<Vec<Chapter>>,
}Expand description
A manga, comic, webtoon, or other type of content for Aidoku to read.
Fields
key: StringUnique identifier for the manga.
title: StringTitle of the manga.
cover: Option<String>Link to the manga cover image.
artists: Option<Vec<String>>Optional list of artists.
Optional list of authors.
description: Option<String>Description of the manga.
url: Option<String>Link to the manga on the source website.
Optional list of genres or tags (max: 255).
status: MangaStatusPublishing status of the manga.
content_rating: ContentRatingContent rating of the manga.
viewer: ViewerPreferred viewer type of the manga.
update_strategy: UpdateStrategyIdeal update strategy for the manga.
next_update_time: Option<i64>Optional date for when the manga should next be updated.
chapters: Option<Vec<Chapter>>List of chapters.
Implementations