pub struct MultiSelectFilter {
pub id: Cow<'static, str>,
pub title: Option<Cow<'static, str>>,
pub hide_from_header: Option<bool>,
pub is_genre: bool,
pub can_exclude: bool,
pub uses_tag_style: bool,
pub options: Vec<Cow<'static, str>>,
pub ids: Option<Vec<Cow<'static, str>>>,
pub default_included: Option<Vec<Cow<'static, str>>>,
pub default_excluded: Option<Vec<Cow<'static, str>>>,
}Expand description
Fields
id: Cow<'static, str>The identifier for this filter.
title: Option<Cow<'static, str>>The display title for this filter.
hide_from_header: Option<bool>Whether this filter should be hidden from the filters list header.
is_genre: boolIndicates if the filter is for genres.
can_exclude: boolWhether options can be excluded as well as included.
uses_tag_style: boolWhether to display the options as tags.
options: Vec<Cow<'static, str>>The list of options to display.
ids: Option<Vec<Cow<'static, str>>>Optional IDs for each option. If not provided, the options are used.
default_included: Option<Vec<Cow<'static, str>>>default_excluded: Option<Vec<Cow<'static, str>>>Trait Implementations
Sourceimpl Clone for MultiSelectFilter
impl Clone for MultiSelectFilter
Sourcefn clone(&self) -> MultiSelectFilter
fn clone(&self) -> MultiSelectFilter
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MultiSelectFilter
impl Debug for MultiSelectFilter
Sourceimpl Default for MultiSelectFilter
impl Default for MultiSelectFilter
Sourceimpl From<MultiSelectFilter> for Filter
impl From<MultiSelectFilter> for Filter
Sourcefn from(value: MultiSelectFilter) -> Filter
fn from(value: MultiSelectFilter) -> Filter
Converts to this type from the input type.
Sourceimpl PartialEq for MultiSelectFilter
impl PartialEq for MultiSelectFilter
impl StructuralPartialEq for MultiSelectFilter