pub struct Page {
pub content: PageContent,
pub thumbnail: Option<String>,
pub has_description: bool,
pub description: Option<String>,
}Expand description
A page for a chapter.
Fields
content: PageContentThe page content.
thumbnail: Option<String>Optional thumbnail image url for the page.
has_description: boolIf the page has a description.
description: Option<String>Optional description for the page.
If has_description is true and this is None, PageDescriptionProvider will be used.
If has_description is false, this field will be ignored.
Implementations
Sourceimpl Page
impl Page
Sourcepub fn ensure_externally_managed(&mut self)
pub fn ensure_externally_managed(&mut self)
Set the page content to be externally managed if it is an image.
This property is exposed for the functions that the register_source macro generates and should not be used directly.