pub struct PageSetting {
pub key: Cow<'static, str>,
pub title: Cow<'static, str>,
pub notification: Option<Cow<'static, str>>,
pub requires: Option<Cow<'static, str>>,
pub requires_false: Option<Cow<'static, str>>,
pub refreshes: Option<Vec<Cow<'static, str>>>,
pub items: Vec<Setting>,
pub inline_title: Option<bool>,
pub auth_to_open: Option<bool>,
pub icon: Option<PageIcon>,
pub info: Option<String>,
}Expand description
Fields
key: Cow<'static, str>The unique key that identifies this setting.
title: Cow<'static, str>The display title for this setting.
notification: Option<Cow<'static, str>>Optional notification to send to the source when this setting is changed.
requires: Option<Cow<'static, str>>Optional key of another setting that must be enabled for this setting to be enabled.
requires_false: Option<Cow<'static, str>>Optional key of another setting that must be disabled for this setting to be enabled.
refreshes: Option<Vec<Cow<'static, str>>>Optional list of items that should be refreshed when this setting changes.
The valid options are:
contentlistingssettings
items: Vec<Setting>The settings contained in this page.
inline_title: Option<bool>Whether to display the title inline.
auth_to_open: Option<bool>Whether to require authentication to open the page.
icon: Option<PageIcon>An icon to be displayed along with the page title.
info: Option<String>An optional string to display under the title in a header view (an icon must also be provided).