pub struct SelectSetting {
pub key: Cow<'static, str>,
pub title: Cow<'static, str>,
pub notification: Option<Cow<'static, str>>,
pub requires: Option<Cow<'static, str>>,
pub requires_false: Option<Cow<'static, str>>,
pub refreshes: Option<Vec<Cow<'static, str>>>,
pub values: Vec<Cow<'static, str>>,
pub titles: Option<Vec<Cow<'static, str>>>,
pub auth_to_open: Option<bool>,
pub default: Option<String>,
}Expand description
Fields
key: Cow<'static, str>The unique key that identifies this setting.
title: Cow<'static, str>The display title for this setting.
notification: Option<Cow<'static, str>>Optional notification to send to the source when this setting is changed.
requires: Option<Cow<'static, str>>Optional key of another setting that must be enabled for this setting to be enabled.
requires_false: Option<Cow<'static, str>>Optional key of another setting that must be disabled for this setting to be enabled.
refreshes: Option<Vec<Cow<'static, str>>>Optional list of items that should be refreshed when this setting changes.
The valid options are:
contentlistingssettings
values: Vec<Cow<'static, str>>The values of the options.
titles: Option<Vec<Cow<'static, str>>>Optional display titles for the options. If not provided, the values will be used as titles.
auth_to_open: Option<bool>Whether to require authentication to open the page for this setting.
default: Option<String>The default selected value. If not provided, the first value will be selected.