pub struct Setting {
pub key: Cow<'static, str>,
pub title: Cow<'static, str>,
pub notification: Option<Cow<'static, str>>,
pub requires: Option<Cow<'static, str>>,
pub requires_false: Option<Cow<'static, str>>,
pub refreshes: Option<Vec<Cow<'static, str>>>,
pub value: SettingValue,
}Expand description
A setting that is shown in the source settings page.
This struct shouldn’t be constructed directly. Instead, use the individual settings structs and call into.
Fields
key: Cow<'static, str>title: Cow<'static, str>notification: Option<Cow<'static, str>>requires: Option<Cow<'static, str>>requires_false: Option<Cow<'static, str>>refreshes: Option<Vec<Cow<'static, str>>>value: SettingValueTrait Implementations
Sourceimpl From<ButtonSetting> for Setting
impl From<ButtonSetting> for Setting
Sourcefn from(button: ButtonSetting) -> Self
fn from(button: ButtonSetting) -> Self
Converts to this type from the input type.
Sourceimpl From<EditableListSetting> for Setting
impl From<EditableListSetting> for Setting
Sourcefn from(source: EditableListSetting) -> Self
fn from(source: EditableListSetting) -> Self
Converts to this type from the input type.
Sourceimpl From<GroupSetting> for Setting
impl From<GroupSetting> for Setting
Sourcefn from(source: GroupSetting) -> Self
fn from(source: GroupSetting) -> Self
Converts to this type from the input type.
Sourceimpl From<LinkSetting> for Setting
impl From<LinkSetting> for Setting
Sourcefn from(source: LinkSetting) -> Self
fn from(source: LinkSetting) -> Self
Converts to this type from the input type.
Sourceimpl From<LoginSetting> for Setting
impl From<LoginSetting> for Setting
Sourcefn from(source: LoginSetting) -> Self
fn from(source: LoginSetting) -> Self
Converts to this type from the input type.
Sourceimpl From<MultiSelectSetting> for Setting
impl From<MultiSelectSetting> for Setting
Sourcefn from(source: MultiSelectSetting) -> Self
fn from(source: MultiSelectSetting) -> Self
Converts to this type from the input type.
Sourceimpl From<PageSetting> for Setting
impl From<PageSetting> for Setting
Sourcefn from(source: PageSetting) -> Self
fn from(source: PageSetting) -> Self
Converts to this type from the input type.
Sourceimpl From<SegmentSetting> for Setting
impl From<SegmentSetting> for Setting
Sourcefn from(source: SegmentSetting) -> Self
fn from(source: SegmentSetting) -> Self
Converts to this type from the input type.
Sourceimpl From<SelectSetting> for Setting
impl From<SelectSetting> for Setting
Sourcefn from(source: SelectSetting) -> Self
fn from(source: SelectSetting) -> Self
Converts to this type from the input type.
Sourceimpl From<StepperSetting> for Setting
impl From<StepperSetting> for Setting
Sourcefn from(source: StepperSetting) -> Self
fn from(source: StepperSetting) -> Self
Converts to this type from the input type.
Sourceimpl From<TextSetting> for Setting
impl From<TextSetting> for Setting
Sourcefn from(source: TextSetting) -> Self
fn from(source: TextSetting) -> Self
Converts to this type from the input type.
Sourceimpl From<ToggleSetting> for Setting
impl From<ToggleSetting> for Setting
Sourcefn from(source: ToggleSetting) -> Self
fn from(source: ToggleSetting) -> Self
Converts to this type from the input type.
impl StructuralPartialEq for Setting