pub struct TextFilter {
pub id: Cow<'static, str>,
pub title: Option<Cow<'static, str>>,
pub hide_from_header: Option<bool>,
pub placeholder: Option<Cow<'static, str>>,
}Expand description
Fields
id: Cow<'static, str>The identifier for this filter.
title: Option<Cow<'static, str>>The display title for this filter.
hide_from_header: Option<bool>Whether this filter should be hidden from the filters list header.
placeholder: Option<Cow<'static, str>>Optional placeholder text to display when the field is empty.