pub struct TextSetting {Show 13 fields
pub key: Cow<'static, str>,
pub title: Cow<'static, str>,
pub notification: Option<Cow<'static, str>>,
pub requires: Option<Cow<'static, str>>,
pub requires_false: Option<Cow<'static, str>>,
pub refreshes: Option<Vec<Cow<'static, str>>>,
pub placeholder: Option<Cow<'static, str>>,
pub autocapitalization_type: Option<i32>,
pub keyboard_type: Option<i32>,
pub return_key_type: Option<i32>,
pub autocorrection_disabled: Option<bool>,
pub secure: Option<bool>,
pub default: Option<Cow<'static, str>>,
}Expand description
Fields
key: Cow<'static, str>The unique key that identifies this setting.
title: Cow<'static, str>The display title for this setting.
notification: Option<Cow<'static, str>>Optional notification to send to the source when this setting is changed.
requires: Option<Cow<'static, str>>Optional key of another setting that must be enabled for this setting to be enabled.
requires_false: Option<Cow<'static, str>>Optional key of another setting that must be disabled for this setting to be enabled.
refreshes: Option<Vec<Cow<'static, str>>>Optional list of items that should be refreshed when this setting changes.
The valid options are:
contentlistingssettings
placeholder: Option<Cow<'static, str>>Optional placeholder text when the field is empty.
autocapitalization_type: Option<i32>The autocapitalization type.
keyboard_type: Option<i32>The keyboard type.
return_key_type: Option<i32>The return key type.
autocorrection_disabled: Option<bool>Whether autocorrection should be disabled.
secure: Option<bool>Whether the text field is for secure entry (password).
default: Option<Cow<'static, str>>The default text value.