pub trait BasicLoginHandler: Source {
// Required method
fn handle_basic_login(
&self,
key: String,
username: String,
password: String,
) -> Result<bool>;
}Expand description
A source that handles basic login with username and password.
This function should return true if the login was successful.
Required Methods
fn handle_basic_login( &self, key: String, username: String, password: String, ) -> Result<bool>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.