DeepLinkHandler

Trait DeepLinkHandler 

pub trait DeepLinkHandler: Source {
    // Required method
    fn handle_deep_link(&self, url: String) -> Result<Option<DeepLinkResult>>;
}
A source that handles deep links.

If a url that is contained in one of the source’s provided base urls is opened in Aidoku, it will be sent to the given source to handle.

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors