pub trait WebLoginHandler: Source {
// Required method
fn handle_web_login(
&self,
key: String,
cookies: HashMap<String, String>,
) -> Result<bool>;
}Expand description
A source that handles custom webview login.
This function will be called whenever cookies are updated, and should return true if the login was successful.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.