pub enum HomeComponentValue {
ImageScroller {
links: Vec<Link>,
auto_scroll_interval: Option<f32>,
width: Option<i32>,
height: Option<i32>,
},
BigScroller {
entries: Vec<Manga>,
auto_scroll_interval: Option<f32>,
},
Scroller {
entries: Vec<Link>,
listing: Option<Listing>,
},
MangaList {
ranking: bool,
page_size: Option<i32>,
entries: Vec<Link>,
listing: Option<Listing>,
},
MangaChapterList {
page_size: Option<i32>,
entries: Vec<MangaWithChapter>,
listing: Option<Listing>,
},
Filters(Vec<FilterItem>),
Links(Vec<Link>),
}Expand description
The value of a component for a home layout.
Variants
ImageScroller
A horizontal scroller of images.
Only the image urls and values of the provided links are used.
BigScroller
A large scroller of manga.
This component displays the title, author, cover image, description, content rating and tags of the provided manga entries.
Scroller
A small scroller of manga.
The subtitles of the provided links are not used.
MangaList
A list of manga.
Fields
MangaChapterList
A list of manga chapters.
The relative time to the chapter’s date uploaded is displayed if provided.
Filters(Vec<FilterItem>)
A collection of links to filtered listings.
Links(Vec<Link>)
A list of links.
Only the link title and values are used.
Implementations
Sourceimpl HomeComponentValue
impl HomeComponentValue
Sourcepub fn empty_image_scroller() -> Self
pub fn empty_image_scroller() -> Self
Creates an empty image scroller component.
Sourcepub fn empty_big_scroller() -> Self
pub fn empty_big_scroller() -> Self
Creates an empty big scroller component.
Sourcepub fn empty_scroller() -> Self
pub fn empty_scroller() -> Self
Creates an empty scroller component.
Sourcepub fn empty_manga_list() -> Self
pub fn empty_manga_list() -> Self
Creates an empty manga list component.
Sourcepub fn empty_manga_chapter_list() -> Self
pub fn empty_manga_chapter_list() -> Self
Creates an empty manga chapter list component.
Sourcepub fn empty_filters() -> Self
pub fn empty_filters() -> Self
Creates an empty filters component.
Sourcepub fn empty_links() -> Self
pub fn empty_links() -> Self
Creates an empty links component.