pub enum SettingValue {
Group {
footer: Option<Cow<'static, str>>,
items: Vec<Setting>,
},
Select {
values: Vec<Cow<'static, str>>,
titles: Option<Vec<Cow<'static, str>>>,
auth_to_open: Option<bool>,
default: Option<String>,
},
MultiSelect {
values: Vec<Cow<'static, str>>,
titles: Option<Vec<Cow<'static, str>>>,
auth_to_open: Option<bool>,
default: Option<Vec<String>>,
},
Toggle {
subtitle: Option<Cow<'static, str>>,
auth_to_disable: Option<bool>,
default: bool,
},
Stepper {
minimum_value: f64,
maximum_value: f64,
step_value: Option<f64>,
default: Option<f64>,
},
Segment {
options: Vec<Cow<'static, str>>,
default: Option<i32>,
},
Text {
placeholder: Option<Cow<'static, str>>,
autocapitalization_type: Option<i32>,
autocorrection_disabled: Option<bool>,
keyboard_type: Option<i32>,
return_key_type: Option<i32>,
secure: Option<bool>,
default: Option<Cow<'static, str>>,
},
Button,
Link {
url: Cow<'static, str>,
external: Option<bool>,
},
Login {
method: LoginMethod,
url: Option<Cow<'static, str>>,
url_key: Option<Cow<'static, str>>,
logout_title: Option<Cow<'static, str>>,
pkce: bool,
token_url: Option<Cow<'static, str>>,
callback_scheme: Option<Cow<'static, str>>,
use_email: bool,
local_storage_keys: Option<Vec<String>>,
},
Page {
items: Vec<Setting>,
inline_title: Option<bool>,
auth_to_open: Option<bool>,
icon: Option<PageIcon>,
info: Option<String>,
},
EditableList {
line_limit: Option<i32>,
inline: bool,
placeholder: Option<Cow<'static, str>>,
default: Option<Vec<Cow<'static, str>>>,
},
}Expand description
The kind of setting.
Variants
Group
A group of settings.
Select
A page that allows selection of a single value.
Fields
MultiSelect
A page that allows selection of multiple values.
Fields
Toggle
A toggle switch.
Fields
Stepper
A numeric stepper control.
Fields
Segment
A segmented control.
Fields
Text
A text input field.
Fields
Button
A clickable button.
Link
A link to a URL.
Fields
Login
A login control.
Fields

method: LoginMethodThe authentication method to use.
Page
A page of settings.
Fields
EditableList
A list that can be edited by the user.