pub enum UpdateStrategy {
Always,
Never,
}Expand description
The preferred update strategy for a manga.
Titles marked as Always will be included in library refreshes by default,
while Never will be excluded. Useful for titles that are known to be fully
completed or have a static chapter list that won’t change after the initial fetch.
Variants