pub trait MigrationHandler: Source {
// Required methods
fn handle_manga_migration(&self, key: String) -> Result<String>;
fn handle_chapter_migration(
&self,
manga_key: String,
chapter_key: String,
) -> Result<String>;
}Expand description
A source that handles key migration.
If a source provides a “breakingChangeVersion” in its configuration, these functions will be called with all of a user’s local manga and chapter keys to migrate them after updating. These functions should return the new key to replace the old one.
Required Methods
fn handle_manga_migration(&self, key: String) -> Result<String>
fn handle_chapter_migration( &self, manga_key: String, chapter_key: String, ) -> Result<String>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.